#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   taffybar
version:                7.2.7
visibility:             public
id:                     taffybar-7.2.7-A5ZOz9cNm1o3CUIZxtWFMg
key:                    taffybar-7.2.7-A5ZOz9cNm1o3CUIZxtWFMg
license:                BSD-3-Clause
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               https://github.com/taffybar/taffybar
synopsis:               A desktop bar similar to xmobar, but with more GUI
description:
    Taffybar is a desktop status bar with GTK widgets for window
    manager state, system information, tray icons, and custom user modules.

category:               System
abi:                    f519981d844ac23b414c7d96bb39758d
exposed:                True
exposed-modules:
    System.Taffybar System.Taffybar.Auth System.Taffybar.Context
    System.Taffybar.Context.Backend System.Taffybar.DBus
    System.Taffybar.DBus.Toggle System.Taffybar.Example
    System.Taffybar.Hooks System.Taffybar.Hyprland
    System.Taffybar.Information.ASUS
    System.Taffybar.Information.AnthropicUsage
    System.Taffybar.Information.Audio
    System.Taffybar.Information.Backlight
    System.Taffybar.Information.Battery
    System.Taffybar.Information.Bluetooth
    System.Taffybar.Information.CPU2
    System.Taffybar.Information.CPUFrequency
    System.Taffybar.Information.ChromeWindowInfo
    System.Taffybar.Information.Crypto
    System.Taffybar.Information.DiskIO
    System.Taffybar.Information.DiskUsage
    System.Taffybar.Information.EWMHDesktopInfo
    System.Taffybar.Information.Hyprland
    System.Taffybar.Information.HyprlandWorkspaceHistory
    System.Taffybar.Information.Inhibitor
    System.Taffybar.Information.KeyboardState
    System.Taffybar.Information.Layout.EWMH
    System.Taffybar.Information.Layout.Hyprland
    System.Taffybar.Information.Layout.Model
    System.Taffybar.Information.MPRIS2
    System.Taffybar.Information.Memory
    System.Taffybar.Information.Network
    System.Taffybar.Information.NetworkManager
    System.Taffybar.Information.Nvidia
    System.Taffybar.Information.OpenAIUsage
    System.Taffybar.Information.PowerProfiles
    System.Taffybar.Information.Privacy
    System.Taffybar.Information.PulseAudio
    System.Taffybar.Information.SafeX11
    System.Taffybar.Information.ScreenLock
    System.Taffybar.Information.StreamInfo
    System.Taffybar.Information.Systemd
    System.Taffybar.Information.Temperature
    System.Taffybar.Information.Wakeup
    System.Taffybar.Information.WirePlumber
    System.Taffybar.Information.Wlsunset
    System.Taffybar.Information.Workspaces.EWMH
    System.Taffybar.Information.Workspaces.Hyprland
    System.Taffybar.Information.Workspaces.Model
    System.Taffybar.Information.Workspaces.Refresh
    System.Taffybar.Information.X11DesktopInfo
    System.Taffybar.Information.XDG.Protocol
    System.Taffybar.LogFormatter System.Taffybar.LogLevels
    System.Taffybar.SimpleConfig System.Taffybar.Support.PagerHints
    System.Taffybar.Util System.Taffybar.Widget
    System.Taffybar.Widget.ASUS System.Taffybar.Widget.AnthropicUsage
    System.Taffybar.Widget.Audio System.Taffybar.Widget.Backlight
    System.Taffybar.Widget.Battery System.Taffybar.Widget.BatteryDonut
    System.Taffybar.Widget.BatteryTextIcon
    System.Taffybar.Widget.Bluetooth
    System.Taffybar.Widget.CPUFrequency
    System.Taffybar.Widget.CPUMonitor
    System.Taffybar.Widget.CommandRunner
    System.Taffybar.Widget.CoordinatedClock
    System.Taffybar.Widget.Crypto System.Taffybar.Widget.DiskIOMonitor
    System.Taffybar.Widget.DiskUsage System.Taffybar.Widget.FSMonitor
    System.Taffybar.Widget.FreedesktopNotifications
    System.Taffybar.Widget.Generic.AutoFillImage
    System.Taffybar.Widget.Generic.AutoSizeImage
    System.Taffybar.Widget.Generic.ChannelGraph
    System.Taffybar.Widget.Generic.ChannelWidget
    System.Taffybar.Widget.Generic.DynamicMenu
    System.Taffybar.Widget.Generic.Graph
    System.Taffybar.Widget.Generic.Icon
    System.Taffybar.Widget.Generic.PollingBar
    System.Taffybar.Widget.Generic.PollingGraph
    System.Taffybar.Widget.Generic.PollingLabel
    System.Taffybar.Widget.Generic.ScalingImage
    System.Taffybar.Widget.Generic.VerticalBar
    System.Taffybar.Widget.HyprlandLayout
    System.Taffybar.Widget.ImageCommandButton
    System.Taffybar.Widget.Inhibitor
    System.Taffybar.Widget.KeyboardState System.Taffybar.Widget.Layout
    System.Taffybar.Widget.MPRIS2 System.Taffybar.Widget.NetworkGraph
    System.Taffybar.Widget.NetworkManager
    System.Taffybar.Widget.NvidiaTemperature
    System.Taffybar.Widget.OmniMenu System.Taffybar.Widget.OpenAIUsage
    System.Taffybar.Widget.PowerProfiles System.Taffybar.Widget.Privacy
    System.Taffybar.Widget.PulseAudio System.Taffybar.Widget.SNIMenu
    System.Taffybar.Widget.SNITray
    System.Taffybar.Widget.SNITray.PrioritizedCollapsible
    System.Taffybar.Widget.ScreenLock
    System.Taffybar.Widget.SimpleClock
    System.Taffybar.Widget.SimpleCommandButton
    System.Taffybar.Widget.Systemd System.Taffybar.Widget.Temperature
    System.Taffybar.Widget.Text.CPUMonitor
    System.Taffybar.Widget.Text.MemoryMonitor
    System.Taffybar.Widget.Text.NetworkMonitor
    System.Taffybar.Widget.Util System.Taffybar.Widget.WakeupDebug
    System.Taffybar.Widget.Weather System.Taffybar.Widget.Windows
    System.Taffybar.Widget.WirePlumber System.Taffybar.Widget.Wlsunset
    System.Taffybar.Widget.Workspaces System.Taffybar.Widget.WttrIn
    System.Taffybar.Widget.XDGMenu.Menu
    System.Taffybar.Widget.XDGMenu.MenuWidget
    System.Taffybar.WidgetPriority System.Taffybar.WindowIcon

hidden-modules:
    Paths_taffybar System.Taffybar.DBus.Client.ChromeWindowInfo
    System.Taffybar.DBus.Client.Login1Manager
    System.Taffybar.DBus.Client.MPRIS2
    System.Taffybar.DBus.Client.NetworkManager
    System.Taffybar.DBus.Client.NetworkManagerAccessPoint
    System.Taffybar.DBus.Client.NetworkManagerActiveConnection
    System.Taffybar.DBus.Client.Params
    System.Taffybar.DBus.Client.PulseAudioCore
    System.Taffybar.DBus.Client.PulseAudioDevice
    System.Taffybar.DBus.Client.PulseAudioServerLookup
    System.Taffybar.DBus.Client.UPower
    System.Taffybar.DBus.Client.UPowerDevice
    System.Taffybar.DBus.Client.Util
    System.Taffybar.Information.Hyprland.API
    System.Taffybar.Information.Hyprland.Types
    System.Taffybar.Information.Workspaces.Support
    System.Taffybar.Information.Wakeup.Manager
    System.Taffybar.Information.Udev
    System.Taffybar.Window.FocusedMonitor

import-dirs:            /usr/lib/ghc-9.6.6/site-local/taffybar-7.2.7
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/taffybar-7.2.7 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/taffybar-7.2.7 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/taffybar
hs-libraries:           HStaffybar-7.2.7-A5ZOz9cNm1o3CUIZxtWFMg
extra-libraries:
    gtk-3 gdk-3 pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0 z udev

extra-libraries-static:
    gtk-3 gdk-3 pangocairo-1.0 Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m
    glycin-2 seccomp lcms2 m pthread atk-bridge-2.0 atspi Xtst Xi
    Xfixes atk-1.0 dbus-1 xkbcommon wayland-cursor wayland-egl
    wayland-client m rt epoxy dl GL EGL pangoft2-1.0 m pango-1.0 m
    fribidi thai datrie Xft cairo m dl fontconfig m expat m Xext
    Xrender X11 pthread xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m
    harfbuzz-gobject harfbuzz m freetype dl bz2 png16 m m brotlidec
    brotlicommon graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0
    atomic m pcre2-8 pthread z mount blkid systemd sysprof-capture-4
    udev

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0 /usr/include
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/glycin-2
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    HStringTemplate-0.8.8-6W4kb8rEptjRfJr67myqD
    X11-1.10.3-4bnVd3SdcvsJN8LDt8CJay
    aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V
    ansi-terminal-1.1-DloTwXdDsLxGyTkENbfyqg base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-65VBuodW2FA1U1zRKEX2Oq
    containers-0.6.7 data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    dbus-1.3.3-14zrP2ElPyi7I7UEc8EF80
    dbus-hslogger-0.1.1.1-1ZTvjkyU0h14bxTXS0tzbf
    dbus-menu-0.1.3.4-nIl8CZKaj9J6wxyqtoY7r directory-1.3.8.5
    disk-free-space-0.1.0.1-EM7dsETQ4QyF5Xspy0kIXr
    dyre-0.9.2-7Le4jOC75atJ5aaluPymeQ
    either-5.0.3-CkgRKJSZ7UH2kTtQpcnCFp
    enclosed-exceptions-1.0.3-JAMZ7NJniZq89V58ZtPXFY filepath-1.4.300.1
    fsnotify-0.4.4.0-Ht4pN2tqCyn6NBcCult6K1
    gi-cairo-connector-0.1.1-GmvBSupoyPM8sKofqC2WCJ
    gi-cairo-render-0.1.2-Kj3foQkl9TH1rrXqbiLLy2
    gi-gdk3-3.0.30-LZ6L4dg06uxEc7qUGSgj84
    gi-gdkpixbuf-2.0.32-7QYwAeBe7NEAQ4LiM2475Y
    gi-gdkx113-3.0.17-DK8abZm9c0rHbOBzU8o4SK
    gi-glib-2.0.30-LmzXQ186UEg90tkBw2C6V9
    gi-gobject-2.0.31-3A9RvIrJNMmKTi9mEMhnXb
    gi-gtk-hs-0.3.18-KCgXlrtHW4iK1l7OKv48pE
    gi-gtk-layer-shell-0.1.7-Ae6D3yrmup4KNg0nBujgdw
    gi-gtk3-3.0.44-L8TX7qBZ6MsFIZhFqqVENc
    gi-pango-1.0.30-31eD3bJeLhs7Cmc8P2wzFG
    gi-wireplumber-0.5.14.2-8GAoa6lfKFOKVdWVvvpxER
    gtk-scaling-image-0.1.0.1-HA3vctd5hSlfBZVHbZoi0
    gtk-sni-tray-0.2.1.4-9H4Vlr8SezhIBj99WETlIm
    gtk-strut-0.1.4.1-Jz4UVbUS0MVKTVCmTCt4KE
    haskell-gi-base-0.26.9-A51M6LjdiVN4RjdHJdLeji
    hslogger-1.3.2.0-5J7cXR4zP7qIvFH1YUzyfL
    http-client-0.7.19-4lCfHST9XIV9y3pAbrfMCv
    http-client-tls-0.3.6.4-HFeZCFLqgZNJXZqGLvkfy8
    http-conduit-2.3.9.1-CxX4k7UIm68ID6VPI4uAFh
    http-types-0.12.4-2JHh5Qo0ssgCXdBZ0yuSfo
    monad-control-1.0.3.1-B6eCGMg4BOZKbaBZ86kHds
    multimap-1.2.1-4W8aWHvVl9g78Tpaptjwyw
    network-3.1.4.0-4Rsy3d52Nm21mbavP5v2o parsec-3.1.16.1
    process-1.6.19.0 rate-limit-1.4.3-6ydvOkN3EwQLZ5xS3sVlHp
    regex-compat-0.95.2.2-DwcD5qxZGc67j8Pwq49pag
    safe-0.3.21-Bi0eBD0gemq14I72arTwzC
    split-0.2.5.1-FQ4kT9wgw7JDP8h2QeY4XG
    status-notifier-item-0.3.2.16-7zpMRh0IIKyKYHcuwuRdck stm-2.5.1.0
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    time-units-1.0.0-5DRkw9RXZDICp7PYN09sTv transformers-0.6.1.0
    tuple-0.3.0.2-BOnlBY1vtubJ5iS5upqFkm unix-2.8.4.0
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    xdg-basedir-0.2.2-DLaKUfv1JJAFBfkP0BUklH
    xdg-desktop-entry-0.1.1.5-9shxkqnd8ucLUgb6y0pkui
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-helpers-1.0.0-4qhWXJoUbtX94cToL5WE9g
    xmonad-0.18.1-HtXbwCOsloJ9brUdBNcu2w
    yaml-0.11.11.2-7C8te7oEKag5lil8hT24q7

haddock-interfaces:     /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:           /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-taffybar-z-testlib
version:              7.2.7
package-name:         taffybar
lib-name:             testlib
id:                   taffybar-7.2.7-99eW7i7KrokCxAhYZyjfHM-testlib
key:                  taffybar-7.2.7-99eW7i7KrokCxAhYZyjfHM-testlib
license:              BSD-3-Clause
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/taffybar/taffybar
synopsis:             A desktop bar similar to xmobar, but with more GUI
description:
    Taffybar is a desktop status bar with GTK widgets for window
    manager state, system information, tray icons, and custom user modules.

category:             System
abi:                  8c85314e38f2615e7d10fefb678b6c91
exposed-modules:
    System.Taffybar.Test.DBusSpec System.Taffybar.Test.UtilSpec
    System.Taffybar.Test.XvfbSpec TestLibSpec

import-dirs:          /usr/lib/ghc-9.6.6/site-local/taffybar-7.2.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/taffybar-7.2.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/taffybar-7.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/taffybar
hs-libraries:         HStaffybar-7.2.7-99eW7i7KrokCxAhYZyjfHM-testlib
depends:
    QuickCheck-2.15.0.1-5Y9HZXtqNX41xwYMFzmoSZ
    attoparsec-0.14.4-qc2ScMijHsIVylJ0k0iua base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    dbus-1.3.3-14zrP2ElPyi7I7UEc8EF80
    extra-1.7.16-JqlpUalRpf3DrrxiVQYUyX filepath-1.4.300.1
    hslogger-1.3.2.0-5J7cXR4zP7qIvFH1YUzyfL
    hspec-2.11.7-CwFT1rdaRmD8UT6wQfam3L
    taffybar-7.2.7-A5ZOz9cNm1o3CUIZxtWFMg text-2.0.2
    typed-process-0.2.13.0-GtejE0dV6Pb8vHOx8VaDLt unix-2.8.4.0
    unliftio-0.2.25.1-JOKqT5DcdDFKqQgMQFlxcn
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/taffybar/html/taffybar.haddock
haddock-html:         /usr/share/doc/taffybar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

